# hackhan_hello
This ia a hello-world project for PyPI.

# Quickstart
Install:
    pip install hackhan-hello

Usage:
    # example.py
    from hello_pypi import hello
    print(hello.hello())
    print(hello.hello_you('jack'))
